summaryrefslogtreecommitdiff
path: root/lbl/os-osf5.h
diff options
context:
space:
mode:
Diffstat (limited to 'lbl/os-osf5.h')
-rw-r--r--lbl/os-osf5.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/lbl/os-osf5.h b/lbl/os-osf5.h
index 4c73c69..5422f18 100644
--- a/lbl/os-osf5.h
+++ b/lbl/os-osf5.h
@@ -21,10 +21,10 @@
/*
* Prototypes missing in Tru64 UNIX 5.x
* XXX - "snprintf()" and "vsnprintf()" aren't missing, but you have to
* #define the right value to get them defined by <stdio.h>.
*/
-int snprintf(char *, size_t, const char *, ...);
-int vsnprintf(char *, size_t, const char *, va_list);
+int pcap_snprintf(char *, size_t, const char *, ...);
+int pcap_vsnprintf(char *, size_t, const char *, va_list);
int pfopen(char *, int);
-
+
@@ -21,10 +21,10 @@
/*
* Prototypes missing in Tru64 UNIX 5.x
- * XXX - "snprintf()" and "vsnprintf()" aren't missing, but you have to
+ * XXX - "pcap_snprintf()" and "pcap_vsnprintf()" aren't missing, but you have to
* #define the right value to get them defined by <stdio.h>.
*/